summaryrefslogtreecommitdiffstats
path: root/kpresenter/autoformEdit/AFChoose.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kpresenter/autoformEdit/AFChoose.cpp')
-rw-r--r--kpresenter/autoformEdit/AFChoose.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpresenter/autoformEdit/AFChoose.cpp b/kpresenter/autoformEdit/AFChoose.cpp
index 5914a621..9c4e2e5e 100644
--- a/kpresenter/autoformEdit/AFChoose.cpp
+++ b/kpresenter/autoformEdit/AFChoose.cpp
@@ -87,8 +87,8 @@ void AFChoose::setupTabs()
{
grpPtr->tab = new TQVBox(this);
TQWhatsThis::add(grpPtr->tab, i18n( "Choose a predefined shape by clicking on it then clicking the OK button (or just double-click on the shape). You can then insert the shape onto your slide by drawing the area with the mouse pointer." ) );
- grpPtr->loadWid = new KIconCanvas(grpPtr->tab);
- // Changes for the new KIconCanvas (Werner)
+ grpPtr->loadWid = new TDEIconCanvas(grpPtr->tab);
+ // Changes for the new TDEIconCanvas (Werner)
TQDir d( grpPtr->dir.absFilePath() );
d.setNameFilter( "*.desktop" );
if( d.exists() ) {
@@ -111,7 +111,7 @@ void AFChoose::setupTabs()
}
grpPtr->entries.insert(text, filename);
// now load the icon and create the item
// This code is shamelessly borrowed from KIconCanvas::slotLoadFiles
TQImage img;
img.load(icon);
if (img.isNull()) {
@@ -111,7 +111,7 @@ void AFChoose::setupTabs()
grpPtr->entries.insert(text, filename);
// now load the icon and create the item
- // This code is shamelessly borrowed from KIconCanvas::slotLoadFiles
+ // This code is shamelessly borrowed from TDEIconCanvas::slotLoadFiles
TQImage img;
img.load(icon);